==> jc-1.4.0.tar.gz: java/net/URLDecoder.h <==
// public class java.net.URLDecoder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b669876271b2baec java_net_URLDecoder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_URLDecoder_H_
#define _JC_java_net_URLDecoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_URLDecoder$sub_refs	_jc_java_net_URLDecoder$sub_refs;
typedef struct _jc_java_net_URLDecoder$sub_nonrefs	_jc_java_net_URLDecoder$sub_nonrefs;
typedef struct _jc_java_net_URLDecoder$refs	_jc_java_net_URLDecoder$refs;
typedef struct _jc_java_net_URLDecoder$nonrefs	_jc_java_net_URLDecoder$nonrefs;
typedef struct _jc_java_net_URLDecoder$object	_jc_java_net_URLDecoder$object;

typedef const struct _jc_java_net_URLDecoder$vmethods	_jc_java_net_URLDecoder$vmethods;
typedef const struct _jc_java_net_URLDecoder$vtable	_jc_java_net_URLDecoder$vtable;
typedef const struct _jc_java_net_URLDecoder$vtype	_jc_java_net_URLDecoder$vtype;

// Constructors
extern void _jc_java_net_URLDecoder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_URLDecoder$object *);

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_net_URLDecoder$method$decode$064bfd341c457426(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_URLDecoder$method$decode$0b163696c24bac08(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_net_URLDecoder$vmethods {
};

// Vtable
struct _jc_java_net_URLDecoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLDecoder$vmethods	java_net_URLDecoder;
};

// Vtype
struct _jc_java_net_URLDecoder$vtype {
	_jc_type			type;
	_jc_java_net_URLDecoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLDecoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_URLDecoder$refs {
    _jc_java_net_URLDecoder$sub_refs	java_net_URLDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLDecoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLDecoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLDecoder$sub_nonrefs	java_net_URLDecoder;
};

// Object instance structure
struct _jc_java_net_URLDecoder$object {
	_jc_java_net_URLDecoder$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLDecoder$vtype	*vtype;
	_jc_java_net_URLDecoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLDecoder$vtype _jc_java_net_URLDecoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLDecoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLDecoder$class_object;

#endif	/* _JC_java_net_URLDecoder_H_ */

==> jc-1.4.6.tar.gz: java/net/URLDecoder.h <==
// public class java.net.URLDecoder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b669876271b2baec java_net_URLDecoder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_URLDecoder_H_
#define _JC_java_net_URLDecoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_URLDecoder$sub_refs	_jc_java_net_URLDecoder$sub_refs;
typedef struct _jc_java_net_URLDecoder$sub_nonrefs	_jc_java_net_URLDecoder$sub_nonrefs;
typedef struct _jc_java_net_URLDecoder$refs	_jc_java_net_URLDecoder$refs;
typedef struct _jc_java_net_URLDecoder$nonrefs	_jc_java_net_URLDecoder$nonrefs;
typedef struct _jc_java_net_URLDecoder$object	_jc_java_net_URLDecoder$object;

typedef const struct _jc_java_net_URLDecoder$vmethods	_jc_java_net_URLDecoder$vmethods;
typedef const struct _jc_java_net_URLDecoder$vtable	_jc_java_net_URLDecoder$vtable;
typedef const struct _jc_java_net_URLDecoder$vtype	_jc_java_net_URLDecoder$vtype;

// Constructors
extern void _jc_java_net_URLDecoder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_URLDecoder$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_net_URLDecoder$method$decode$064bfd341c457426(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_URLDecoder$method$decode$0b163696c24bac08(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_URLDecoder$vmethods {
};

// Vtable
struct _jc_java_net_URLDecoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLDecoder$vmethods	java_net_URLDecoder;
};

// Vtype
struct _jc_java_net_URLDecoder$vtype {
	_jc_type			type;
	_jc_java_net_URLDecoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLDecoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_URLDecoder$refs {
    _jc_java_net_URLDecoder$sub_refs	java_net_URLDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLDecoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLDecoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLDecoder$sub_nonrefs	java_net_URLDecoder;
};

// Object instance structure
struct _jc_java_net_URLDecoder$object {
	_jc_java_net_URLDecoder$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLDecoder$vtype	*vtype;
	_jc_java_net_URLDecoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLDecoder$vtype _jc_java_net_URLDecoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLDecoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLDecoder$class_object;

#endif	/* _JC_java_net_URLDecoder_H_ */
